@@ -19,7 +19,7 @@
  */
 
 
-#include <QtTest>
+#include <QtTest/QTest>
 
 #include "view/structures/datatypes/array/arraydatainformation.h"
 #include "view/structures/datatypes/array/primitivearraydata.h"
@@ -257,40 +257,40 @@ void BasicDataInformationTest::initTestCase()
     LoggerWithContext lwc(0, QString());
 
 	for (int i = Type_START; i < Type_Bitfield; ++i) {
-		primitives.append(PrimitiveFactory::newInstance(QLatin1String("prim"),
+		primitives.append(PrimitiveFactory::newInstance(QStringLiteral("prim"),
 		        PrimitiveDataType(static_cast<PrimitiveDataTypeEnum>(i)), lwc));
 	}
-	QCOMPARE(PrimitiveFactory::newInstance(QLatin1String("invalid"), Type_Bitfield, lwc), static_cast<PrimitiveDataInformation*>(0));
-	QCOMPARE(PrimitiveFactory::newInstance(QLatin1String("invalid"), QLatin1String("invalid_type"), lwc), static_cast<PrimitiveDataInformation*>(0));
-	bitfields.append(new BoolBitfieldDataInformation(QLatin1String("bitfield"), 24));
-	bitfields.append(new UnsignedBitfieldDataInformation(QLatin1String("bitfield"), 24));
-	bitfields.append(new SignedBitfieldDataInformation(QLatin1String("bitfield"), 24));
+	QCOMPARE(PrimitiveFactory::newInstance(QStringLiteral("invalid"), Type_Bitfield, lwc), static_cast<PrimitiveDataInformation*>(0));
+	QCOMPARE(PrimitiveFactory::newInstance(QStringLiteral("invalid"), QStringLiteral("invalid_type"), lwc), static_cast<PrimitiveDataInformation*>(0));
+	bitfields.append(new BoolBitfieldDataInformation(QStringLiteral("bitfield"), 24));
+	bitfields.append(new UnsignedBitfieldDataInformation(QStringLiteral("bitfield"), 24));
+	bitfields.append(new SignedBitfieldDataInformation(QStringLiteral("bitfield"), 24));
 
-	emptyStruct = new StructureDataInformation(QLatin1String("emptyStruct"));
+	emptyStruct = new StructureDataInformation(QStringLiteral("emptyStruct"));
 	QVector<DataInformation*> structChildren;
-	structChildren << PrimitiveFactory::newInstance(QLatin1String("prim"), Type_UInt32, lwc)
-	        << PrimitiveFactory::newInstance(QLatin1String("prim2"), Type_UInt64, lwc);
-	structWithChildren = new StructureDataInformation(QLatin1String("structWithChildren"), structChildren);
+	structChildren << PrimitiveFactory::newInstance(QStringLiteral("prim"), Type_UInt32, lwc)
+	        << PrimitiveFactory::newInstance(QStringLiteral("prim2"), Type_UInt64, lwc);
+	structWithChildren = new StructureDataInformation(QStringLiteral("structWithChildren"), structChildren);
 
-	emptyUnion = new UnionDataInformation(QLatin1String("emptyUnion"));
+	emptyUnion = new UnionDataInformation(QStringLiteral("emptyUnion"));
     QVector<DataInformation*> unionChildren;
-    unionChildren << PrimitiveFactory::newInstance(QLatin1String("prim"), Type_UInt32, lwc)
-            << PrimitiveFactory::newInstance(QLatin1String("prim2"), Type_UInt64, lwc);
-	unionWithChildren = new UnionDataInformation(QLatin1String("unionWithChildren"), unionChildren);
+    unionChildren << PrimitiveFactory::newInstance(QStringLiteral("prim"), Type_UInt32, lwc)
+            << PrimitiveFactory::newInstance(QStringLiteral("prim2"), Type_UInt64, lwc);
+	unionWithChildren = new UnionDataInformation(QStringLiteral("unionWithChildren"), unionChildren);
 
-	emptyPrimitiveArray = new ArrayDataInformation(QLatin1String("emptyPrimitiveArray"), 0, PrimitiveFactory::newInstance(QLatin1String("prim"), Type_UInt32, lwc));
-	emptyComplexArray = new ArrayDataInformation(QLatin1String("emptyComplexArray"), 0, structWithChildren->clone());
-	primitiveArrayWithChildren = new ArrayDataInformation(QLatin1String("primitiveArrayWithChildren"), 2, PrimitiveFactory::newInstance(QLatin1String("prim"), Type_UInt32, lwc));
-	complexArrayWithChildren = new ArrayDataInformation(QLatin1String("complexArrayWithChildren"), 2, structWithChildren->clone());
+	emptyPrimitiveArray = new ArrayDataInformation(QStringLiteral("emptyPrimitiveArray"), 0, PrimitiveFactory::newInstance(QStringLiteral("prim"), Type_UInt32, lwc));
+	emptyComplexArray = new ArrayDataInformation(QStringLiteral("emptyComplexArray"), 0, structWithChildren->clone());
+	primitiveArrayWithChildren = new ArrayDataInformation(QStringLiteral("primitiveArrayWithChildren"), 2, PrimitiveFactory::newInstance(QStringLiteral("prim"), Type_UInt32, lwc));
+	complexArrayWithChildren = new ArrayDataInformation(QStringLiteral("complexArrayWithChildren"), 2, structWithChildren->clone());
 
 	QMap<AllPrimitiveTypes, QString> enumVals;
-	enumVals[1] = QLatin1String("one");
-	enumVals[2] = QLatin1String("two");
-	enumVals[4] = QLatin1String("four");
-	EnumDefinition::Ptr edef(new EnumDefinition(enumVals, QLatin1String("eDef"), Type_UInt32));
-	flagData = new FlagDataInformation(QLatin1String("flagData"), PrimitiveFactory::newInstance(QLatin1String("prim"), Type_UInt32, lwc), edef);
-	enumData = new EnumDataInformation(QLatin1String("enumData"), PrimitiveFactory::newInstance(QLatin1String("prim"), Type_UInt32, lwc), edef);
-    emptyString = new StringDataInformation(QLatin1String("string"), StringDataInformation::ASCII);
+	enumVals[1] = QStringLiteral("one");
+	enumVals[2] = QStringLiteral("two");
+	enumVals[4] = QStringLiteral("four");
+	EnumDefinition::Ptr edef(new EnumDefinition(enumVals, QStringLiteral("eDef"), Type_UInt32));
+	flagData = new FlagDataInformation(QStringLiteral("flagData"), PrimitiveFactory::newInstance(QStringLiteral("prim"), Type_UInt32, lwc), edef);
+	enumData = new EnumDataInformation(QStringLiteral("enumData"), PrimitiveFactory::newInstance(QStringLiteral("prim"), Type_UInt32, lwc), edef);
+    emptyString = new StringDataInformation(QStringLiteral("string"), StringDataInformation::ASCII);
     dummy = new DummyDataInformation(0);
     topLevel = new TopLevelDataInformation(new DummyDataInformation(0));
 }
@@ -427,7 +427,7 @@ void BasicDataInformationTest::cleanupTestCase()
     delete topLevel;
 }
 
-QTEST_MAIN(BasicDataInformationTest)
+QTEST_GUILESS_MAIN(BasicDataInformationTest)
 
 
 #include "basicdatainformationtest.moc"
