@@ -24,20 +24,22 @@
 #define BOOKMARKSTOOLFACTORY_H
 
 // lib
-#include <kasten/okteta/oktetakastencontrollers_export.h>
+#include "oktetakastencontrollers_export.h"
 // Kasten core
-#include <kasten/abstracttoolfactory.h>
+#include <abstracttoolfactory.h>
 
-namespace Kasten {
+
+namespace Kasten
+{
 
 class OKTETAKASTENCONTROLLERS_EXPORT BookmarksToolFactory : public AbstractToolFactory
 {
-public:
+  public:
     BookmarksToolFactory();
-    ~BookmarksToolFactory() override;
+    virtual ~BookmarksToolFactory();
 
-public: // AbstractToolFactory API
-    AbstractTool* create() override;
+  public: // AbstractToolFactory API
+    virtual AbstractTool* create();
 };
 
 }
