@@ -27,17 +27,17 @@
 // lib
 #include <addresscombobox.h>
 #include <addressvalidator.h>
-// KDE
-#include <KPushButton>
+// KF5
+#include <QPushButton>
 #include <KGuiItem>
-#include <KLocale>
+#include <KLocalizedString>
 // Qt
-#include <QtGui/QCheckBox>
-#include <QtGui/QLabel>
-#include <QtGui/QLayout>
+#include <QCheckBox>
+#include <QLabel>
+#include <QLayout>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 GotoOffsetView::GotoOffsetView( GotoOffsetTool* tool, QWidget* parent )
@@ -53,12 +53,12 @@ GotoOffsetView::GotoOffsetView( GotoOffsetTool* tool, QWidget* parent )
 
     QLabel* label = new QLabel( i18nc("@label:listbox","O&ffset:"), this );
     mAddressEdit = new Okteta::AddressComboBox( this );
-    connect( mAddressEdit, SIGNAL(addressChanged(Okteta::Address)),
-             mTool, SLOT(setTargetOffset(Okteta::Address)) );
-    connect( mAddressEdit, SIGNAL(formatChanged(int)),
-             SLOT(onFormatChanged(int)) );
-    connect( mAddressEdit, SIGNAL(addressTypeChanged(int)),
-             SLOT(onAddressTypeChanged(int)) );
+    connect( mAddressEdit, &Okteta::AddressComboBox::addressChanged,
+             mTool, &GotoOffsetTool::setTargetOffset );
+    connect( mAddressEdit, &Okteta::AddressComboBox::formatChanged,
+             this, &GotoOffsetView::onFormatChanged );
+    connect( mAddressEdit, &Okteta::AddressComboBox::addressTypeChanged,
+             this, &GotoOffsetView::onAddressTypeChanged );
     label->setBuddy( mAddressEdit );
     const QString inputWhatsThis =
         i18nc( "@info:whatsthis","Enter an offset to go to, or select a previous offset from the list." );
@@ -80,17 +80,17 @@ GotoOffsetView::GotoOffsetView( GotoOffsetTool* tool, QWidget* parent )
     mAtCursorCheckBox = new QCheckBox( i18nc("@option:check","From c&ursor"), this );
     mAtCursorCheckBox->setWhatsThis(
         i18nc("@info:whatsthis","Go relative from the current cursor location and not absolute.") );
-    connect( mAtCursorCheckBox, SIGNAL(toggled(bool)),
-             mTool, SLOT(setIsRelative(bool)) );
+    connect( mAtCursorCheckBox, &QCheckBox::toggled,
+             mTool, &GotoOffsetTool::setIsRelative );
     mExtendSelectionCheckBox = new QCheckBox( i18nc("@option:check","&Extend selection"), this );
     mExtendSelectionCheckBox->setWhatsThis(
         i18nc("@info:whatsthis","Extend the selection by the cursor move.") );
-    connect( mExtendSelectionCheckBox, SIGNAL(toggled(bool)),
-             mTool, SLOT(setIsSelectionToExtent(bool)) );
+    connect( mExtendSelectionCheckBox, &QCheckBox::toggled,
+             mTool, &GotoOffsetTool::setIsSelectionToExtent );
     mBackwardsCheckBox = new QCheckBox( i18nc("@option:check","&Backwards"), this );
     mBackwardsCheckBox->setWhatsThis(
         i18nc("@info:whatsthis","Go backwards from the end or the current cursor location.") );
-    connect( mBackwardsCheckBox, SIGNAL(toggled(bool)), mTool, SLOT(setIsBackwards(bool)) );
+    connect( mBackwardsCheckBox, &QCheckBox::toggled, mTool, &GotoOffsetTool::setIsBackwards );
 
     QHBoxLayout* upperOptionsLayout = new QHBoxLayout();
     upperOptionsLayout->setMargin( 0 );
@@ -105,15 +105,16 @@ GotoOffsetView::GotoOffsetView( GotoOffsetTool* tool, QWidget* parent )
     // Goto button
     const KGuiItem gotoGuiItem =
         KGuiItem( i18nc("@action:button","&Go"),
-                  QLatin1String("go-jump"),
+                  QStringLiteral("go-jump"),
                   i18nc("@info:tooltip",
                         "Go to the Offset"),
-                  i18nc("@info:whatsthis",
-                        "If you press the <interface>Go</interface> "
-                        "button, the cursor will be moved in the document to or, "
-                        "on your option, by the offset you entered above.") );
-    mGotoButton = new KPushButton( gotoGuiItem, this );
-    connect( mGotoButton, SIGNAL(clicked(bool)), SLOT(onGotoButtonClicked()) );
+                  xi18nc("@info:whatsthis",
+                         "If you press the <interface>Go</interface> "
+                         "button, the cursor will be moved in the document to or, "
+                         "on your option, by the offset you entered above.") );
+    mGotoButton = new QPushButton( this );
+    KGuiItem::assign( mGotoButton, gotoGuiItem );
+    connect( mGotoButton, &QPushButton::clicked, this, &GotoOffsetView::onGotoButtonClicked );
     addButton( mGotoButton, AbstractToolWidget::Default );
     baseLayout->addWidget( mGotoButton );
     baseLayout->setAlignment( mGotoButton, Qt::AlignTop );
@@ -123,8 +124,8 @@ GotoOffsetView::GotoOffsetView( GotoOffsetTool* tool, QWidget* parent )
     setTabOrder( mBackwardsCheckBox, mExtendSelectionCheckBox );
     setTabOrder( mExtendSelectionCheckBox, mGotoButton );
 
-    connect( mTool, SIGNAL(isApplyableChanged(bool)),
-             SLOT(onApplyableChanged(bool)) );
+    connect( mTool, &GotoOffsetTool::isApplyableChanged,
+             this, &GotoOffsetView::onApplyableChanged );
 
     onApplyableChanged( mTool->isApplyable() );
 }
