@@ -24,7 +24,8 @@
 #define ENDIANNESS_H
 
 // Qt
-#include <Qt>
+#include <QtCore/Qt>
+
 
 enum Endianness
 {
@@ -32,6 +33,7 @@ enum Endianness
     BigEndian =    1 // Sun, Motorola, ...
 };
 
+
 static const Endianness ThisMachineEndianness =
 #if Q_BYTE_ORDER == Q_LITTLE_ENDIAN
     LittleEndian;
