@@ -1,7 +1,7 @@
 /*
     This file is part of the Okteta Kasten module, made within the KDE community.
 
-    Copyright 2010,2012 Friedrich W. H. Kossebau <kossebau@kde.org>
+    Copyright 2010,2012-2013 Friedrich W. H. Kossebau <kossebau@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Lesser General Public
@@ -26,19 +26,40 @@
 #include "viewprofileedit.h"
 // Okteta Gui Kasten
 #include <bytearrayviewprofile.h>
+// Qt
+#include <QtWidgets/QVBoxLayout>
+#include <QtWidgets/QPushButton>
+#include <QtWidgets/QDialogButtonBox>
 
 
-namespace Kasten2
+namespace Kasten
 {
 
 ViewProfileEditDialog::ViewProfileEditDialog( QWidget* parent )
-  : KDialog( parent )
+  : QDialog( parent )
 {
     mViewProfileEdit = new ViewProfileEdit( this );
-    connect( mViewProfileEdit, SIGNAL(profileTitleChanged(QString)), SLOT(onProfileTitleChanged(QString)) );
+
+    // dialog buttons
+    QDialogButtonBox* dialogButtonBox = new QDialogButtonBox(QDialogButtonBox::Ok
+                                                             | QDialogButtonBox::Cancel);
+    connect(dialogButtonBox, &QDialogButtonBox::accepted, this, &QDialog::accept );
+    connect(dialogButtonBox, &QDialogButtonBox::rejected, this, &QDialog::reject );
+
+    // main layout
+    QVBoxLayout* layout = new QVBoxLayout;
+    layout->addWidget( mViewProfileEdit );
+    layout->addStretch();
+    layout->addWidget( dialogButtonBox );
+    setLayout( layout );
+
+    dialogButtonBox->button( QDialogButtonBox::Cancel )->setDefault( true );
+
+    connect( mViewProfileEdit, &ViewProfileEdit::profileTitleChanged,
+             this, &ViewProfileEditDialog::onProfileTitleChanged );
     // Disable it by default
-    enableButtonOk( false );
-    setMainWidget( mViewProfileEdit );
+    mOkButton = dialogButtonBox->button( QDialogButtonBox::Ok );
+    mOkButton->setEnabled( false );
 }
 
 ByteArrayViewProfile ViewProfileEditDialog::viewProfile() const
@@ -56,7 +77,7 @@ void ViewProfileEditDialog::setViewProfile( const ByteArrayViewProfile& viewProf
 
 void ViewProfileEditDialog::onProfileTitleChanged(const QString& title)
 {
-    enableButtonOk( !title.isEmpty() );
+    mOkButton->setEnabled( !title.isEmpty() );
 }
 
 ViewProfileEditDialog::~ViewProfileEditDialog()
